@@ -17,26 +17,26 @@
 #'
 #' @return Depending on the return_type, it either returns a list of PDB IDs (if "entry")
 #'         or the full response from the API.
-#'         
+#'
 #' @importFrom httr POST content
 #' @importFrom jsonlite toJSON fromJSON
-#' 
+#'
 #' @examples
 #' # Get a list of PDBs for a specific search term
 #' pdbs <- query_search("ribosome")
-#' 
+#'
 #' # Search by PubMed ID Number
 #' pdbs <- query_search(search_term = 27499440, query_type = "PubmedIdQuery")
-#' 
+#'
 #' # Search by source organism using NCBI TaxId
 #' pdbs <- query_search(search_term = "6239", query_type = "TreeEntityQuery")
-#' 
+#'
 #' @export
 
 query_search <- function(search_term, query_type = "full_text", return_type = "entry", scan_params = NULL, num_attempts = 1, sleep_time = 0.5) {
   # Define query subtype as NULL initially
   query_subtype <- NULL
-  
+
   # Adjust query_type and query_subtype based on input
   if (query_type == "PubmedIdQuery") {
     query_type <- "text"
@@ -69,16 +69,16 @@ query_search <- function(search_term, query_type = "full_text", return_type = "e
     query_type <- "text"
     query_subtype <- "uniprot"
   }
-  
+
   # Check for valid query_type and return_type
   stopifnot(query_type %in% c("full_text", "text", "structure", "sequence", "seqmotif", "chemical"),
             return_type %in% c("entry", "polymer_entity"))
-  
+
   # Initialize query parameters
   query_params <- list()
   query_params$type <- "terminal"
   query_params$service <- query_type
-  
+
   # Handle different query types
   if (query_type %in% c("full_text", "text")) {
     query_params$parameters <- list(value = search_term)
@@ -87,7 +87,7 @@ query_search <- function(search_term, query_type = "full_text", return_type = "e
   } else if (query_type == "structure") {
     query_params$parameters <- list(operator = "relaxed_shape_match", value = list(entry_id = search_term, assembly_id = "1"))
   }
-  
+
   # Apply query_subtype conditions if applicable
   if (!is.null(query_subtype)) {
     if (query_subtype == "pmid") {
@@ -106,34 +106,43 @@ query_search <- function(search_term, query_type = "full_text", return_type = "e
       query_params$parameters <- list(operator = "exact_match", negation = FALSE, value = as.character(search_term), attribute = "rcsb_polymer_entity_container_identifiers.reference_sequence_identifiers.database_accession")
     }
   }
-  
+
   # Define the base query parameters
   scan_params <- list(query = query_params, return_type = return_type, request_options = list(results_verbosity = "verbose"))
-  
+
   # Additional handling for 'entry' return type
   if (return_type == "entry") {
     scan_params$request_options$return_all_hits <- TRUE
   }
-  
 
   url <- "https://search.rcsb.org/rcsbsearch/v2/query?json="
 
-      query_text <- toJSON(scan_params, auto_unbox = TRUE, pretty = TRUE)
+  query_text <- toJSON(scan_params, auto_unbox = TRUE, pretty = TRUE)
 
-      for (attempt in 1:num_attempts) {
-        response <- POST(url, body = query_text, encode = "json")
-        if (!is.null(response) && http_status(response)$category == "Success") {
-          response_val <- fromJSON(content(response, "text", encoding = "UTF-8"))
-
-          if (return_type == "entry") {
-            idlist <- walk_nested_dict(response_val, "identifier", maxdepth = 25, outputs = list())
-            return(idlist[[1]])
-          } else {
-            return(response_val)
-          }
-        }
-        Sys.sleep(sleep_time)
+  for (attempt in 1:num_attempts) {
+    response <- tryCatch(
+      {
+        POST(url, body = query_text, encode = "json")
+      },
+      error = function(e) {
+        warning("HTTP request failed on attempt ", attempt, ": ", e$message)
+        NULL
       }
+    )
 
-      stop("Retrieval failed, returning NULL")
+    if (!is.null(response) && http_status(response)$category == "Success") {
+      response_val <- fromJSON(content(response, "text", encoding = "UTF-8"))
+
+      if (return_type == "entry") {
+        idlist <- walk_nested_dict(response_val, "identifier", maxdepth = 25, outputs = list())
+        return(idlist[[1]])
+      } else {
+        return(response_val)
+      }
     }
+    Sys.sleep(sleep_time)
+  }
+
+  warning("All retrieval attempts failed, returning NULL")
+  return(NULL)
+}
